.. image:: https://badge.fury.io/py/PyPubSub.svg
    :target: https://badge.fury.io/py/PyPubSub
.. image:: https://img.shields.io/travis/schollii/pypubsub.svg
    :target: https://img.shields.io/travis/schollii/pypubsub
    
News
====

January 2019: pypubsub 4.0.3 released!

Overview
========

Provides a publish-subscribe API to facilitate event-based or message-based
architecture in a single-process application. It is pure Python and works on
Python 3.3+. It is centered on the notion of a topic; senders publish
messages of a given topic, and listeners subscribe to messages of a given
topic, all inside the same process. The package also supports a variety of
advanced features that facilitate debugging and maintaining topics
and messages in larger desktop- or server-based applications.

Install most recent stable with "pip install pypubsub".

Useful links:

- Project on PyPI: https://pypi.python.org/pypi/PyPubSub
- The documentation for latest stable release is at
  http://pypubsub.readthedocs.io.
- The documentation for latest code is at
  http://pypubsub.readthedocs.io/en/latest.


